Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(156)

Unified Diff: ash/mus/property_util.h

Issue 2430593002: mash: Use ash shell window container ids instead of ash::mojom::Container (Closed)
Patch Set: rebase Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/mus/disconnected_app_handler.cc ('k') | ash/mus/property_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/mus/property_util.h
diff --git a/ash/mus/property_util.h b/ash/mus/property_util.h
index 1e9a0a89f035c5b483457ea200e4b4014ffaa395..0e19e901f46b396bcf349c6ba76410d0a72262e0 100644
--- a/ash/mus/property_util.h
+++ b/ash/mus/property_util.h
@@ -6,7 +6,6 @@
#define ASH_MUS_PROPERTY_UTIL_H_
#include "ash/public/interfaces/ash_window_type.mojom.h"
-#include "ash/public/interfaces/container.mojom.h"
#include "services/ui/public/cpp/window.h"
#include "services/ui/public/interfaces/window_manager_constants.mojom.h"
#include "ui/wm/public/window_types.h"
@@ -37,11 +36,10 @@ gfx::Rect GetWindowUserSetBounds(const ui::Window* window);
void SetWindowPreferredSize(ui::Window* window, const gfx::Size& size);
gfx::Size GetWindowPreferredSize(const ui::Window* window);
-// If |window| has the |kWindowContainer_Property| set as a property, then
-// the value of |kWindowContainer_Property| is set in |container| and true is
-// returned. Otherwise false is returned.
-bool GetRequestedContainer(const ui::Window* window,
- mojom::Container* container);
+// If |window| has the |kInitialContainerId_Property| set as a property, then
+// the value of |kInitialContainerId_Property| is set in |container_id| and true
+// is returned. Otherwise false is returned.
+bool GetRequestedContainer(const ui::Window* window, int* container_id);
// Returns a bitfield of kResizeBehavior* values from
// window_manager_constants.mojom.
« no previous file with comments | « ash/mus/disconnected_app_handler.cc ('k') | ash/mus/property_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698